package com.tongran.mtragent.mapper;

import com.tongran.mtragent.domain.AllMtrClient;

import java.util.List;

/**
 * mtr探测丢包clinetId记录Mapper接口
 * 
 * @author tongran
 * @date 2025-11-24
 */
public interface AllMtrClientMapper 
{
    /**
     * 查询mtr探测丢包clinetId记录
     * 
     * @param id mtr探测丢包clinetId记录主键
     * @return mtr探测丢包clinetId记录
     */
    public AllMtrClient selectAllMtrClientById(Long id);

    /**
     * 查询mtr探测丢包clinetId记录列表
     * 
     * @param allMtrClient mtr探测丢包clinetId记录
     * @return mtr探测丢包clinetId记录集合
     */
    public List<AllMtrClient> selectAllMtrClientList(AllMtrClient allMtrClient);

    /**
     * 新增mtr探测丢包clinetId记录
     * 
     * @param allMtrClient mtr探测丢包clinetId记录
     * @return 结果
     */
    public int insertAllMtrClient(AllMtrClient allMtrClient);

    /**
     * 修改mtr探测丢包clinetId记录
     * 
     * @param allMtrClient mtr探测丢包clinetId记录
     * @return 结果
     */
    public int updateAllMtrClient(AllMtrClient allMtrClient);

    /**
     * 删除mtr探测丢包clinetId记录
     * 
     * @param id mtr探测丢包clinetId记录主键
     * @return 结果
     */
    public int deleteAllMtrClientById(Long id);

    /**
     * 批量删除mtr探测丢包clinetId记录
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteAllMtrClientByIds(Long[] ids);

    /**
     * 批量新增
     * @param allMtrClientList
     * @return
     */
    int batchInsertAllMtrClient(List<AllMtrClient> allMtrClientList);
}
